# Require core library
require "middleman-core"

# Extension namespace
module Middleman
  module DeployWithNotifications

    class Options < Struct.new(:whatisthis, :method, :host, :port, :user, :password, :path, :clean, :remote, :branch, :after_build, :airbrake_api_key, :hipchat_rooms, :hipchat_token, :revision, :revision_short, :deploy_user, :github_project, :github_user, :git_branch, :git_comment); end

    class << self

      def options
        @@options
      end

      def registered(app, options_hash={}, &block)
        options = Options.new(options_hash)
        yield options if block_given?

        options.port ||= 22
        options.clean ||= false
        options.remote ||= "origin"
        options.branch ||= "gh-pages"

        options.after_build ||= false

        options.revision        = `git rev-parse HEAD`.gsub( /\s*$/, '' ).chomp
        options.revision_short  = `git rev-parse --short HEAD`.gsub( /\s*$/, '' ).chomp
        options.deploy_user     = `git config --get github.user`.chomp
        options.github_user, options.github_project = `git remote -v | grep "/" | head -n1`.gsub( /.*:([\w_-]+)\/([\w_\.-]+).git.*/, '\1/\2' ).split( "/" )
        options.github_project.chomp!

        options.git_branch          = `git rev-parse --abbrev-ref HEAD`.gsub( /\s*/, '' ).chomp
        options.git_comment         = `git log -1 --pretty=%B`.gsub( /\s*$/, '' ).chomp

        app.after_build do |builder|
          ::Middleman::Cli::DeployWithNotifications.new.deploy if options.after_build
        end

        @@options = options

        app.send :include, Helpers
      end

      alias :included :registered

    end

    module Helpers
      def options
        ::Middleman::DeployWithNotifications.options
      end
    end

  end
end
